@@ -1,6 +1,6 @@
 SEXP
-    Matrix_DSym,
     Matrix_DIsqrtSym,
+    Matrix_DSym,
     Matrix_DimSym,
     Matrix_GpSym,
     Matrix_LSym,
@@ -13,14 +13,17 @@ SEXP
     Matrix_RXXSym,
     Matrix_RZXSym,
     Matrix_XtXSym,
-    Matrix_ZtXSym,
+    Matrix_ZZpOSym,
     Matrix_ZZxSym,
+    Matrix_ZtXSym,
+    Matrix_ZtZSym,
     Matrix_bVarSym,
     Matrix_cnamesSym,
-    Matrix_devianceSym,
     Matrix_devCompSym,
+    Matrix_devianceSym,
     Matrix_diagSym,
     Matrix_factorization,
+    Matrix_flistSym,
     Matrix_iSym,
     Matrix_ipermSym,
     Matrix_jSym,
