@@ -35,6 +35,7 @@ static R_CallMethodDef CallEntries[] = {
     {"csc_getDiag", (DL_FUNC) &csc_getDiag, 1},
     {"csc_transpose", (DL_FUNC) &csc_transpose, 1},
     {"csc_matrix_mm", (DL_FUNC) &csc_matrix_mm, 2},
+    {"cscBlocked_2cscMatrix", (DL_FUNC) &cscBlocked_2cscMatrix, 1},
     {"lsq_dense_Chol", (DL_FUNC) &lsq_dense_Chol, 2},
     {"lsq_dense_QR", (DL_FUNC) &lsq_dense_QR, 2},
     {"lapack_qr", (DL_FUNC) &lapack_qr, 2},
@@ -66,6 +67,7 @@ static R_CallMethodDef CallEntries[] = {
     {"lmer_ECMEsteps", (DL_FUNC) &lmer_ECMEsteps, 4},
     {"lmer_gradient", (DL_FUNC) &lmer_gradient, 3},
     {"lmer_variances", (DL_FUNC) &lmer_variances, 1},
+    {"lmer_Crosstab", (DL_FUNC) &lmer_Crosstab, 1},
     {"poMatrix_rcond", (DL_FUNC) &poMatrix_rcond, 2},
     {"poMatrix_solve", (DL_FUNC) &poMatrix_solve, 1},
     {"poMatrix_matrix_solve", (DL_FUNC) &poMatrix_matrix_solve, 2},
